@@ -112,6 +112,10 @@ class Autotest
         options[:no_full_after_failed] = true
       end
 
+      opts.on "-d", "--debug", "Debug mode, for reporting bugs." do
+        options[:debug] = true
+      end
+
       opts.on "-v", "--verbose", "Be annoyingly verbose (debugs .autotest)." do
         options[:verbose] = true
       end
@@ -279,10 +283,10 @@ class Autotest
     @child = nil
 
     self.completed_re =
-      /\d+ tests, \d+ assertions, \d+ failures, \d+ errors(, \d+ skips)?/
+      /\d+ (tests|runs), \d+ assertions, \d+ failures, \d+ errors(, \d+ skips)?/
     self.extra_class_map   = {}
     self.extra_files       = []
-    self.failed_results_re = /^\s+\d+\) (?:Failure|Error):\n(.*?)\((.*?)\)/
+    self.failed_results_re = /^\s*\d+\) (?:Failure|Error):\n(.*?)(?: [\(\[](.*?)[\)\]])?:$/
     self.files_to_test     = new_hash_of_arrays
     self.find_order        = []
     self.known_files       = nil
@@ -291,7 +295,7 @@ class Autotest
     self.output            = $stderr
     self.prefix            = nil
     self.sleep             = 1
-    self.testlib           = "test/unit"
+    self.testlib           = "minitest/autorun"
     specified_directories  = ARGV.reject { |arg| arg.start_with?("-") } # options are not directories
     self.find_directories  = specified_directories.empty? ? ['.'] : specified_directories
     self.unit_diff         = nil
@@ -316,6 +320,30 @@ class Autotest
     end
   end
 
+  def debug
+    require "pp"
+    find_files_to_test
+
+    puts "Known test files:"
+    puts
+    pp files_to_test.keys.sort
+
+    class_map = self.class_map
+
+    puts
+    puts "Known class map:"
+    puts
+    pp class_map
+  end
+
+  def class_map
+    class_map = Hash[*self.find_order.grep(/^test/).map { |f| # TODO: ugly
+                       [path_to_classname(f), f]
+                     }.flatten]
+    class_map.merge! self.extra_class_map
+    class_map
+  end
+
   ##
   # Repeatedly run failed tests, then all tests, then wait for changes
   # and carry on until killed.
@@ -329,6 +357,8 @@ class Autotest
 
     self.last_mtime = Time.now if options[:no_full_after_start]
 
+    self.debug if options[:debug]
+
     loop do
       begin # ^c handler
         get_to_green
@@ -344,6 +374,7 @@ class Autotest
       end
     end
     hook :quit
+    puts
   rescue Exception => err
     hook(:died, err) or raise err
   end
@@ -483,10 +514,7 @@ class Autotest
   def consolidate_failures failed
     filters = new_hash_of_arrays
 
-    class_map = Hash[*self.find_order.grep(/^test/).map { |f| # TODO: ugly
-                       [path_to_classname(f), f]
-                     }.flatten]
-    class_map.merge! self.extra_class_map
+    class_map = self.class_map
 
     failed.each do |method, klass|
       if class_map.has_key? klass then
@@ -564,7 +592,11 @@ class Autotest
 
   def handle_results results
     results = results.gsub(/\e\[\d+m/, '') # strip ascii color
-    failed = results.scan self.failed_results_re
+    failed = results.scan(self.failed_results_re).map { |m, k|
+      k, m = $1, $2 if m =~ /(\w+)\#(\w+)/ # minitest 5 output
+      [m, k]
+    }
+
     completed = results[self.completed_re]
 
     if completed then
@@ -603,6 +635,13 @@ class Autotest
   # Generate the commands to test the supplied files
 
   def make_test_cmd files_to_test
+    if options[:debug] then
+      puts "Files to test:"
+      puts
+      pp files_to_test
+      puts
+    end
+
     cmds = []
     full, partial = reorder(files_to_test).partition { |k,v| v.empty? }
     diff = self.unit_diff
@@ -689,16 +728,22 @@ class Autotest
   # proc.
 
   def test_files_for filename
-    result = @test_mappings.find { |file_re, ignored| filename =~ file_re }
+    result = []
 
-    p :test_file_for => [filename, result.first] if result and $DEBUG
+    @test_mappings.each do |file_re, proc|
+      if filename =~ file_re then
+        result = [proc.call(filename, $~)].
+          flatten.sort.uniq.select { |f| known_files[f] }
+        break unless result.empty?
+      end
+    end
 
-    result = result.nil? ? [] : [result.last.call(filename, $~)].flatten
+    p :test_file_for => [filename, result.first] if result and options[:debug]
 
     output.puts "No tests matched #{filename}" if
       (options[:verbose] or $TESTING) and result.empty?
 
-    result.sort.uniq.select { |f| known_files[f] }
+    return result
   end
 
   ##
