@@ -139,7 +139,7 @@ end
 
 class TestTrueClass; end
 
-class TestZenTest < MiniTest::Unit::TestCase
+class TestZenTest < Minitest::Test
   def setup
     @tester = ZenTest.new()
   end
@@ -187,7 +187,7 @@ class Something
   end
 end
 
-class TestSomething < MiniTest::Unit::TestCase
+class TestSomething < Minitest::Test
   def test_class_method3
     raise NotImplementedError, 'Need to write test_class_method3'
   end
@@ -451,11 +451,11 @@ end
   end
 
   def test_load_file
-    # HACK raise NotImplementedError, 'Need to write test_load_file'
+    skip 'Need to write test_load_file'
   end
 
   def test_scan_files
-    # HACK raise NotImplementedError, 'Need to write test_scan_files'
+    skip 'Need to write test_scan_files'
   end
 
   def test_process_class
@@ -508,13 +508,13 @@ end
   HEADER = "\nrequire 'test/unit/testcase'\nrequire 'test/unit' if $0 == __FILE__\n\n"
 
   def test_testcase1
-    expected = "#{HEADER}class Blah1\n  def missingimpl(*args)\n    raise NotImplementedError, 'Need to write missingimpl'\n  end\nend\n\nclass TestBlah1 < MiniTest::Unit::TestCase\n  def test_missingtest\n    raise NotImplementedError, 'Need to write test_missingtest'\n  end\nend\n\n# Number of errors detected: 2"
+    expected = "#{HEADER}class Blah1\n  def missingimpl(*args)\n    raise NotImplementedError, 'Need to write missingimpl'\n  end\nend\n\nclass TestBlah1 < Minitest::Test\n  def test_missingtest\n    raise NotImplementedError, 'Need to write test_missingtest'\n  end\nend\n\n# Number of errors detected: 2"
 
     assert_equal expected, util_testcase("Blah1", "TestBlah1")
   end
 
   def test_testcase2
-    expected = "#{HEADER}class Something2::Blah2\n  def missingimpl(*args)\n    raise NotImplementedError, 'Need to write missingimpl'\n  end\nend\n\nclass TestSomething2::TestBlah2 < MiniTest::Unit::TestCase\n  def test_missingtest\n    raise NotImplementedError, 'Need to write test_missingtest'\n  end\nend\n\n# Number of errors detected: 2"
+    expected = "#{HEADER}class Something2::Blah2\n  def missingimpl(*args)\n    raise NotImplementedError, 'Need to write missingimpl'\n  end\nend\n\nclass TestSomething2::TestBlah2 < Minitest::Test\n  def test_missingtest\n    raise NotImplementedError, 'Need to write test_missingtest'\n  end\nend\n\n# Number of errors detected: 2"
 
 assert_equal expected, util_testcase("Something2::Blah2", "TestSomething2::TestBlah2")
   end
@@ -526,31 +526,31 @@ assert_equal expected, util_testcase("Something2::Blah2", "TestSomething2::TestB
   end
 
   def test_testcase4
-    expected = "#{HEADER}class TestBlah4 < MiniTest::Unit::TestCase\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\n\n  def test_missingtest2\n    raise NotImplementedError, 'Need to write test_missingtest2'\n  end\nend\n\n# Number of errors detected: 3"
+    expected = "#{HEADER}class TestBlah4 < Minitest::Test\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\n\n  def test_missingtest2\n    raise NotImplementedError, 'Need to write test_missingtest2'\n  end\nend\n\n# Number of errors detected: 3"
 
     assert_equal expected, util_testcase("Blah4")
   end
 
   def test_testcase5
-    expected = "#{HEADER}class TestMyHash5 < MiniTest::Unit::TestCase\n  def test_index\n    raise NotImplementedError, 'Need to write test_index'\n  end\n\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\nend\n\n# Number of errors detected: 3"
+    expected = "#{HEADER}class TestMyHash5 < Minitest::Test\n  def test_index\n    raise NotImplementedError, 'Need to write test_index'\n  end\n\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\nend\n\n# Number of errors detected: 3"
 
     assert_equal expected, util_testcase("MyHash5")
   end
 
   def test_testcase6
-    expected = "#{HEADER}class TestMyModule6::TestMyClass6 < MiniTest::Unit::TestCase\n  def test_index\n    raise NotImplementedError, 'Need to write test_index'\n  end\n\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\nend\n\n# Number of errors detected: 3"
+    expected = "#{HEADER}class TestMyModule6::TestMyClass6 < Minitest::Test\n  def test_index\n    raise NotImplementedError, 'Need to write test_index'\n  end\n\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\nend\n\n# Number of errors detected: 3"
 
     assert_equal expected, util_testcase("MyModule6::MyClass6")
   end
 
   def test_testcase7
-    expected = "#{HEADER}class TestMyModule7::TestMyClass7 < MiniTest::Unit::TestCase\n  def test_index\n    raise NotImplementedError, 'Need to write test_index'\n  end\n\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\nend\n\n# Number of errors detected: 3"
+    expected = "#{HEADER}class TestMyModule7::TestMyClass7 < Minitest::Test\n  def test_index\n    raise NotImplementedError, 'Need to write test_index'\n  end\n\n  def test_missingtest1\n    raise NotImplementedError, 'Need to write test_missingtest1'\n  end\nend\n\n# Number of errors detected: 3"
 
     assert_equal expected, util_testcase("MyModule7::MyClass7")
   end
 
   def test_testcase8
-    expected = "#{HEADER}class TestMyClass8 < MiniTest::Unit::TestCase\n  def test_class_foobar\n    raise NotImplementedError, 'Need to write test_class_foobar'\n  end\n\n  def test_class_foobaz\n    raise NotImplementedError, 'Need to write test_class_foobaz'\n  end\nend\n\n# Number of errors detected: 3"
+    expected = "#{HEADER}class TestMyClass8 < Minitest::Test\n  def test_class_foobar\n    raise NotImplementedError, 'Need to write test_class_foobar'\n  end\n\n  def test_class_foobaz\n    raise NotImplementedError, 'Need to write test_class_foobaz'\n  end\nend\n\n# Number of errors detected: 3"
 
     assert_equal expected, util_testcase("MyClass8")
   end
@@ -566,7 +566,7 @@ assert_equal expected, util_testcase("Something2::Blah2", "TestSomething2::TestB
     pims = TrueClass.public_instance_methods(false)
     TrueClass.send :remove_method, :inspect if pims.include? :inspect # 2.0 only
 
-    expected = "#{HEADER}class TestTrueClass < MiniTest::Unit::TestCase\n  def test_and\n    raise NotImplementedError, 'Need to write test_and'\n  end\n\n  def test_carat\n    raise NotImplementedError, 'Need to write test_carat'\n  end\n\n  def test_or\n    raise NotImplementedError, 'Need to write test_or'\n  end\n\n  def test_to_s\n    raise NotImplementedError, 'Need to write test_to_s'\n  end\nend\n\n# Number of errors detected: 4"
+    expected = "#{HEADER}class TestTrueClass < Minitest::Test\n  def test_and\n    raise NotImplementedError, 'Need to write test_and'\n  end\n\n  def test_carat\n    raise NotImplementedError, 'Need to write test_carat'\n  end\n\n  def test_or\n    raise NotImplementedError, 'Need to write test_or'\n  end\n\n  def test_to_s\n    raise NotImplementedError, 'Need to write test_to_s'\n  end\nend\n\n# Number of errors detected: 4"
 
     assert_equal expected, util_testcase("TestTrueClass")
   end
